@@ -27,7 +27,7 @@ import numpy
 
 from math import floor
 from .base import HDUBase, IMAGE_HDU
-from ..util import IS_PY3, array_to_native
+from ..util import IS_PY3, array_to_native, copy_if_needed
 
 # for python3 compat
 if IS_PY3:
@@ -146,7 +146,7 @@ class ImageHDU(HDUBase):
         if IS_PY3 and img_send.dtype.char == 'U':
             # for python3, we convert unicode to ascii
             # this will error if the character is not in ascii
-            img_send = img_send.astype('S', copy=False)
+            img_send = img_send.astype('S', copy=copy_if_needed)
 
         if not numpy.isscalar(start):
             # convert to scalar offset
@@ -278,8 +278,11 @@ class ImageHDU(HDUBase):
                     step = -1
 
             # Sanity checks for proper syntax.
-            if (step > 0 and stop < start) or (step < 0 and start < stop):
+            if ((step > 0 and stop < start)
+                    or (step < 0 and start < stop)
+                    or (start == stop)):
                 return numpy.empty(0, dtype=npy_dtype)
+
             if start < 0:
                 start = dims[dim] + start
                 if start < 0:
@@ -293,6 +296,7 @@ class ImageHDU(HDUBase):
 
             if stop > dims[dim]:
                 stop = dims[dim]
+
             if stop < start:
                 # A little black magic here.  The stop is offset by 2 to
                 # accommodate the 1-offset of CFITSIO, and to move past the end
