@@ -219,3 +219,139 @@ def test_compress_preserve_zeros():
 
                     for zind in zinds:
                         assert rdata[zind[0], zind[1]] == 0.0
+
+
+@pytest.mark.parametrize(
+    'compress',
+    [
+        'rice',
+        'hcompress',
+        'plio',
+    ]
+)
+@pytest.mark.parametrize(
+    'seed_type',
+    ['matched', 'unmatched', 'checksum', 'checksum_int'],
+)
+@pytest.mark.parametrize(
+    'use_fits_object',
+    [False, True],
+)
+@pytest.mark.parametrize(
+    'dtype',
+    ['f4', 'f8'],
+)
+def test_compressed_seed(compress, seed_type, use_fits_object, dtype):
+    """
+    Test writing and reading a rice compressed image
+    """
+    nrows = 5
+    ncols = 20
+
+    qlevel = 16
+
+    seed = 1919
+    rng = np.random.RandomState(seed)
+
+    if seed_type == 'matched':
+        # dither_seed = 9881
+        dither_seed1 = 9881
+        dither_seed2 = 9881
+    elif seed_type == 'unmatched':
+        # dither_seed = None
+        dither_seed1 = 3
+        dither_seed2 = 4
+    elif seed_type == 'checksum':
+        dither_seed1 = 'checksum'
+        dither_seed2 = b'checksum'
+    elif seed_type == 'checksum_int':
+        dither_seed1 = -1
+        # any negative means use checksum
+        dither_seed2 = -3
+
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname1 = os.path.join(tmpdir, 'test1.fits')
+        fname2 = os.path.join(tmpdir, 'test2.fits')
+
+        data = rng.normal(size=(nrows, ncols))
+        if compress == 'plio':
+            data = data.clip(min=0)
+        data = data.astype(dtype)
+
+        if use_fits_object:
+            with FITS(fname1, 'rw') as fits1:
+                fits1.write(
+                    data, compress=compress, qlevel=qlevel,
+                    # dither_seed=dither_seed,
+                    dither_seed=dither_seed1,
+                )
+                rdata1 = fits1[-1].read()
+
+            with FITS(fname2, 'rw') as fits2:
+                fits2.write(
+                    data, compress=compress, qlevel=qlevel,
+                    # dither_seed=dither_seed,
+                    dither_seed=dither_seed2,
+                )
+                rdata2 = fits2[-1].read()
+        else:
+            write(
+                fname1, data, compress=compress, qlevel=qlevel,
+                # dither_seed=dither_seed,
+                dither_seed=dither_seed1,
+            )
+            rdata1 = read(fname1)
+
+            write(
+                fname2, data, compress=compress, qlevel=qlevel,
+                # dither_seed=dither_seed,
+                dither_seed=dither_seed2,
+            )
+            rdata2 = read(fname2)
+
+        mess = "%s compressed images ('%s')" % (compress, dtype)
+
+        if seed_type in ['checksum', 'checksum_int', 'matched']:
+            assert np.all(rdata1 == rdata2), mess
+        else:
+            assert np.all(rdata1 != rdata2), mess
+
+
+@pytest.mark.parametrize(
+    'dither_seed',
+    ['blah', 10_001],
+)
+def test_compressed_seed_bad(dither_seed):
+    """
+    Test writing and reading a rice compressed image
+    """
+    compress = 'rice'
+    dtype = 'f4'
+    nrows = 5
+    ncols = 20
+
+    qlevel = 16
+
+    seed = 1919
+    rng = np.random.RandomState(seed)
+
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(tmpdir, 'test.fits')
+
+        data = rng.normal(size=(nrows, ncols))
+        data = data.astype(dtype)
+
+        with pytest.raises(ValueError):
+            write(
+                fname, data, compress=compress, qlevel=qlevel,
+                dither_seed=dither_seed,
+            )
+
+
+if __name__ == '__main__':
+    test_compressed_seed(
+        compress='rice',
+        match_seed=False,
+        use_fits_object=True,
+        dtype='f4',
+    )
